<?php
/**
 * MTS Simple Booking カレンダー表示処理クラスモジュール
 *
 * @Filename    MtssbCalendarView.php
 * @Author      S.Hayashi
 * @Date        2014-11-05 at Ver.1.19.0
 */
class MtssbCalendarView
{
    // 月リンク出力データキャッシュ
    private $pagination = '';

    // 予約フォームリンク
    private $formUrl = '';

    public function __construct()
    {
        // 予約フォームページのURL
        $this->formUrl = get_permalink(get_page_by_path(MTS_Simple_Booking::PAGE_BOOKING_FORM));
    }

    /**
     * カレンダータイトル表示
     *
     */
    public function calendarTitle($params)
    {
        // Widgetかタイトルがなければ何も出力しない
        if ($params['widget'] || empty($params['title'])) {
            return '';
        }

        // カレンダータイトル
		/*
        return apply_filters('mtssb_calendar_title',
            sprintf('<h3 class="calendar-title">%s</h3>', $params['title']), $params['calendar_id']);
			*/
    }

    /**
     * カレンダーのキャプション表示
     *
     */
    public function captionPagination($params, MtssbCalendar $calendar)
    {
        // キャプション非表示(キャプション、月リンク共に非表示)
        if ($params['caption'] != '1' && $params['pagination'] < 2) {
            return '';
        }

        // キャプション
        $capstr = '';
        if ($params['caption'] == '1') {
            $capstr = apply_filters('mtssb_caption',
                date_i18n(__('F, Y'), $calendar->calendarTime),
                array('month' => $calendar->calendarTime, 'cid' => $params['calendar_id']));
        }

        // 翌月のページリンク
        $pagstr = '';
        if ($params['pagination'] == 2 || $params['pagination'] == 3) {
            $pagstr = $this->pagination($params, $calendar);
        }

        // キャプション(ページリンク)表示
        //return sprintf('<caption class="calendar-caption">%s%s</caption>', $capstr, $pagstr) . "\n";
    }

    /**
     * 予約カレンダーのページリンク表示
     *
     */
    public function pagination($params, MtssbCalendar $calendar)
    {
        // 既にページネーション出力を生成していればそれを戻す
        if ($this->pagination) {
            return $this->pagination;
        }

        // カレンダー年月
        $year = date_i18n('Y', $calendar->calendarTime);
        $month = date_i18n('m', $calendar->calendarTime);

        // リンク
        $cid = $params['calendar_id'];
        $prevtime = mktime(0, 0, 0, $month - 1, 1, $year);
        $prev_title = esc_html(
            apply_filters('mtssb_prev_pagination', date_i18n(__('F, Y'), $prevtime), array('prev' => $prevtime, 'cid' => $cid))
        );
        $prev_arg = array('ym' => date_i18n('Y-n', $prevtime)) + (empty($cid) ? array() : array('cid' => $cid));

        $nexttime = mktime(0, 0, 0, $month + 1, 1, $year);
        $next_title = esc_html(
            apply_filters('mtssb_next_pagination', date_i18n(__('F, Y'), $nexttime), array('next' => $nexttime, 'cid' => $cid))
        );
        $next_arg = array('ym' => date_i18n('Y-n', $nexttime)) + (empty($cid) ? array() : array('cid' => $cid));

        $anchor = $params['anchor'] ? "#{$params['anchor']}" : '';

        ob_start();
?>
        <div class="monthly-prev-next">
			<ul>
				<li>
					<?php
					if ($calendar->monthTime <= $prevtime) {
						echo sprintf('<a href="%s%s" class="prev left_arrow">%s</a>', htmlspecialchars(add_query_arg($prev_arg)), $anchor, $prev_title);
					} else {
						echo sprintf('<a href="#" class="prev left_arrow"><span class="no-link">%s</span></a>', $prev_title);
					} ?>
				</li>
				<li class="this_month">
				<?php
				echo esc_html(
					apply_filters('mtssb_prev_pagination', date_i18n(__('F, Y'), mktime(0, 0, 0, $month, 1, $year)), array('prev' => mktime(0, 0, 0, $month, 1, $year), 'cid' => $cid))
				);		
				?>
				</li>
				<li>
					<?php
					if ($nexttime < $calendar->openTime) {
						echo sprintf('<a href="%s%s" class="next right_arrow">%s</a>', htmlspecialchars(add_query_arg($next_arg)), $anchor, $next_title);
					} else {
						echo sprintf('<a href="#" class="next right_arrow"><span class="no-link">%s</span></a>', $next_title);
					} ?>
				</li>
			</ul>
			<div class="this_month_sm">
				<p>
					<?php
					echo esc_html(
						apply_filters('mtssb_prev_pagination', date_i18n(__('F, Y'), mktime(0, 0, 0, $month, 1, $year)), array('prev' => mktime(0, 0, 0, $month, 1, $year), 'cid' => $cid))
					);		
					?>
				</p>
			</div>
		</div>



<?php
        return $this->pagination = ob_get_clean();
    }

    /**
     * 月カレンダーの曜日ヘッダー表示
     *
     * @calTime     カレンダー先頭のUnix Time
     * @paramWeek   ショートコード曜日列引数
     */
    public function weekHeader($calTime, $paramWeek)
    {
        $weeks = explode(',', $paramWeek);

        for ($i = 0; $i < 7; $i++, $calTime += 86400) {
            $weekClass[$i] = strtolower(date('D', $calTime));
            $weekNo = date_i18n('w', $calTime);
            $weekNames[$i] = !empty($weeks[$weekNo]) ? $weeks[$weekNo] : date_i18n('D', $calTime);
        }

        ob_start();
?>
        <thead>
        <tr class="header-row"><?php for ($i = 0; $i < 7; $i++) {
                echo sprintf('<th class="week-title %s">%s</th>', $weekClass[$i], $weekNames[$i]);
            } ?>
        </thead>

<?php
        return ob_get_clean();
    }

    /**
     * 指定日予約時間割カレンダー表示
     *
     * $daytime		unix time
     * $params		ショートコードパラメータ
     */
    public function timetableLink($dayTime, $params, $article, $timetableInfo)
    {
        $aParam = array('aid' => $article['article_id'], 'cid' => $params['calendar_id']);

        ob_start();
?>





<div id="calender" class="page calender timeselect">
	
	<div class="calender_footer">
		<ul class="fix_del">
			<li class="vacant"><span>〇</span>予約可</li>
			<li class="low"><span>△</span>残り僅か</li>
			<li class="low_ng"><span>×</span>満室</li>
			<li class="disable"><span>ー</span>予約不可</li>
		</ul>
	</div>
	<div class="monthly-calendar day-calendar">
        <table class="mtssb-timetable-link">
            <caption><?php echo $this->timetableCaption($dayTime, $article['name'], $aParam) ?></caption>
            <tr>
                <th class="day-left"><?php echo str_replace("予約", "利用開始時間", $article['name']) ?></th>
                <th class="day-right"><?php
                    echo apply_filters('mtssb_daily_booking_title', __('Booking', MTS_Simple_Booking::DOMAIN), $aParam);
                ?></th>
            </tr>

	    <?php 
		$url_array = array(); 
		$counter_url = -1;
		$counter_view = -1;
		$check_flag = 0;
	    ?>
            <?php foreach ($timetableInfo as $theTime => $timeInfo) :
                $marking = $timeInfo->marking ? $timeInfo->marking : $timeInfo->remain;
                $param = $aParam + array('mark' => $timeInfo->mark, 'remain' => $timeInfo->remain);
                $linktext = apply_filters('mtssb_daily_mark', $marking, $param);
                if ($timeInfo->mark != 'disable' && $timeInfo->mark != 'full' && $params['link']) {
                    $url_array[] = esc_url(add_query_arg(array('aid' => $article['article_id'], 'utm' => $dayTime + $theTime), $this->formUrl));

                }
                //$linktext .= $timeInfo->names ? " ({$timeInfo->names})" : '';
            ?><?php endforeach; ?>


            <?php foreach ($timetableInfo as $theTime => $timeInfo) :
                $not_flag++;
                $marking = $timeInfo->marking ? $timeInfo->marking : $timeInfo->remain;
                $param = $aParam + array('mark' => $timeInfo->mark, 'remain' => $timeInfo->remain);
                $linktext = apply_filters('mtssb_daily_mark', $marking, $param);
		if($linktext == "×" && $check_flag == 0){
			$counter_url++;
			$check_flag = 1;
		}
                if ($timeInfo->mark != 'disable' && $timeInfo->mark != 'full' && $params['link']) {
   			if($counter_url == -1){
                 		$linktext = sprintf('<a class="booking-timelink" href="%s">%s</a>',
                       		 $url_array[0],
                     		 $linktext);
			}
			else{
                            if($check_flag == 1){
                 		$linktext = "×";
                            }else{
                 		$linktext = sprintf('<a class="booking-timelink" href="%s">%s</a>',
                	        $url_array[$counter_url],
        	                $linktext);
                            }
			}
			$counter_url++;
			if($check_flag == 1){
				$counter_url--;
				$check_flag = 0;
			}

                }
		$counter_view++;
                $linktext .= $timeInfo->names ? " ({$timeInfo->names})" : '';
            ?>
		<?php
			$counter_view_count = 0;
			$week = explode( '(',$this->timetableCaption($dayTime, $article['name'], $aParam));
			$week_1 = str_replace(")", "",$week[1]);
			//echo $week_1;
			if((strpos($week_1, "日") === FALSE)){
				if((strpos($week_1, "土") === FALSE)){
					$week_1 = 13;
					
				}else{
					$week_1 = 10;
					//$counter_view_count = 1;
				}
			}else{
				$week_1 = 10;
				$counter_view_count = 1;
			}
			
		?>
		<?php if($counter_view > $counter_view_count && $counter_view < $week_1 ) :?><tr>
                <th class="day-left"><?php
                    $param = $aParam + array('time' => $theTime);
                    echo apply_filters('mtssb_time_header', date('H:i', $theTime), $param) ?></th>
                <td class="day-right"><div class="calendar-mark <?php echo $timeInfo->mark ?>"><?php echo $linktext ?></div></td>
            </tr><?php endif; ?><?php endforeach; ?>
        </table>
	</div>
</div>

<?php
        return ob_get_clean();
    }

    /**
     * 予約カレンダーのタイトル表示
     *
     */
    public function timetableCaption($dayTime, $name, $aParam)
    {
        $title = apply_filters('mtssb_timetable_name', $name, $aParam);
        $aParam += array('day' => $dayTime);

        $date = apply_filters('mtssb_timetable_date', date_i18n('Y年n月j日 (D)', $dayTime), $aParam);

        return sprintf('<div class="mtssb-timetable-name">%s</div><div class="mtssb-timetable-date">%s</div>', $title, $date);
    }

    /**
     * 指定日予約時間割セレクトボックス表示
     *
     * $daytime		unix time
     * $params		ショートコードパラメータ
     */
    public function timetableSelect($dayTime, $params, $article, $timetableInfo)
    {
        $aParam = array('aid' => $article['article_id'], 'cid' => $params['calendar_id']);

        ob_start();
?>
        <form method="post" action="<?php echo $this->formUrl ?>" class="mtssb-timetable-form">
            <?php echo $this->timetableCaption($dayTime, $article['name'], $aParam); ?>

            <fieldset class="select-timetable">
                <select class="timetable-select" name="utm">
                    <?php foreach ($timetableInfo as $theTime => $timeInfo) {
                        echo $this->_selectOption($dayTime + $theTime, $timeInfo, $aParam);
                    } ?>
                </select>
                <button type="submit" class="timetable-submit">
                    <?php echo apply_filters('mtssb_daily_timetable_submit', '予約フォーム', $aParam) ?>
                </button>
            </fieldset>
            <input type="hidden" name="aid" value="<?php echo $article['article_id'] ?>" />
        </form>

<?php
        return ob_get_clean();
    }

    private function _selectOption($bookingTime, $timeInfo, $aParam)
    {
        // 表示マーキング(マーキング　または　残数)
        $marking = $timeInfo->marking ? $timeInfo->marking : $timeInfo->remain;

        // 予約者名
        $names = $timeInfo->names ? sprintf(' (%s)', $timeInfo->names) : '';

        // オプション表示文字列
        $param = $aParam + array('time' => $bookingTime, 'mark' => $timeInfo->mark, 'remain' => $timeInfo->remain);

        $string = sprintf('%s %s%s', date_i18n('H時i分', $bookingTime), $marking, $names);
        $string = apply_filters('mtssb_timetable_select_option', $string, $param);

        // 選択可否
        $disabled = ($timeInfo->mark == 'disable' || $timeInfo->mark == 'full') ? ' disabled="disabled"' : '';

        return sprintf('<option value="%s"%s>%s</option>', $bookingTime, $disabled, $string);
    }

}